@@ -9,10 +9,13 @@ use std::{
 
 mod error_std;
 
+/// All reversed error.
+pub type Except<T> = std::result::Result<TailwindError, T>;
 /// All result about tailwind
 pub type Result<T> = std::result::Result<T, TailwindError>;
 /// Maybe have ast position
 pub type MaybeRanged = Option<Range<usize>>;
+
 /// Error type for all tailwind operators
 #[derive(Debug)]
 pub struct TailwindError {
@@ -51,6 +54,14 @@ pub enum TailwindErrorKind {
     // UnknownError(#[from] anyhow::Error),
 }
 
+/// Reverse except type
+pub fn unexpected<T>(e: Except<T>) -> Result<T> {
+    match e {
+        Ok(v) => Err(v),
+        Err(e) => Ok(e),
+    }
+}
+
 impl TailwindError {
     /// Set a local path for the error
     #[inline]
