@@ -5,4 +5,4 @@
 mod error;
 mod error_3rd;
 
-pub use self::error::{MaybeRanged, Result, TailwindError, TailwindErrorKind};
+pub use self::error::{unexpected, Except, MaybeRanged, Result, TailwindError, TailwindErrorKind};
